seaborn\_extensions package
===========================

Submodules
----------

seaborn\_extensions.annotated\_clustermap module
------------------------------------------------

.. automodule:: seaborn_extensions.annotated_clustermap
   :members:
   :undoc-members:
   :show-inheritance:

seaborn\_extensions.swarmboxenplot module
-----------------------------------------

.. automodule:: seaborn_extensions.swarmboxenplot
   :members:
   :undoc-members:
   :show-inheritance:

seaborn\_extensions.types module
--------------------------------

.. automodule:: seaborn_extensions.types
   :members:
   :undoc-members:
   :show-inheritance:

seaborn\_extensions.utils module
--------------------------------

.. automodule:: seaborn_extensions.utils
   :members:
   :undoc-members:
   :show-inheritance:

seaborn\_extensions.volcano module
----------------------------------

.. automodule:: seaborn_extensions.volcano
   :members:
   :undoc-members:
   :show-inheritance:

seaborn\_extensions.volcano2 module
-----------------------------------

.. automodule:: seaborn_extensions.volcano2
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: seaborn_extensions
   :members:
   :undoc-members:
   :show-inheritance:
